@@ -9,8 +9,8 @@
 #
 package TAP::SimpleOutput;
 our $AUTHORITY = 'cpan:RSRCHBOY';
-# git description: 0.003-10-g9419a7a
-$TAP::SimpleOutput::VERSION = '0.004';
+# git description: 0.006-0-gc9adab7
+$TAP::SimpleOutput::VERSION = '0.007';
 
 # ABSTRACT: Simple closure-driven TAP generator
 
@@ -18,11 +18,18 @@ use strict;
 use warnings;
 
 use Sub::Exporter::Progressive -setup => {
-    exports => [
-        qw{ counters counters_and_levelset counters_as_hashref },
-    ],
+    exports => [ qw{
+        counters counters_and_levelset counters_as_hashref
+        subtest_header subtest_header_needed
+    } ],
+    groups => {
+        default => [],
+        subtest => [ qw{ subtest_header subtest_header_needed } ],
+    },
 };
 
+use Carp 'croak';
+use Class::Load 'try_load_class';
 
 
 sub counters {
@@ -74,6 +81,38 @@ sub _build_counters {
     );
 }
 
+
+my $_subtest_header_needed;
+sub subtest_header_needed {
+
+    return $_subtest_header_needed
+        if defined $_subtest_header_needed;
+
+    do {
+        my ($success, $error) = try_load_class $_;
+        croak __PACKAGE__ . " needs $_, but can't find it: $error"
+            unless $success;
+    } for qw{ Perl::Version Test::More };
+
+    return $_subtest_header_needed
+        = Perl::Version->new(Test::More->VERSION) >= Perl::Version->new('0.98_05');
+}
+
+sub _subtest_header_indent { $INC{'Test/Stream.pm'} ? q{} : (' ' x 4) }
+
+
+sub subtest_header {
+    my ($out, $name) = @_;
+
+    $out = $out->{freeform}
+        if ref $out && ref $out eq 'HASH';
+
+    return subtest_header_needed()
+        ? $out->(_subtest_header_indent . "# Subtest: $name")
+        : q{}
+        ;
+}
+
 !!42;
 
 __END__
@@ -92,7 +131,7 @@ TAP::SimpleOutput - Simple closure-driven TAP generator
 
 =head1 VERSION
 
-This document describes version 0.004 of TAP::SimpleOutput - released November 01, 2016 as part of TAP-SimpleOutput.
+This document describes version 0.007 of TAP::SimpleOutput - released November 08, 2016 as part of TAP-SimpleOutput.
 
 =head1 SYNOPSIS
 
@@ -202,6 +241,38 @@ adjust the level of the counters.
 
 This is not something you're likely to need.
 
+=head2 subtest_header_needed()
+
+Returns true if the level of Test::More available will output a subtest header.
+
+Note that this function will attempt to load L<Test::More> and L<Perl::Version>.
+If either of these packages are unavailable, it will L<Carp/croak>.
+
+=head2 subtest_header()
+
+Given an output coderef (e.g. the 'freeform' from counters() or
+counters_as_hashref()) and a subtest name (that is, a string), we return a
+subtest header appropriately indented for the level of Test::More available.
+
+e.g.
+
+    my $out = counters_as_hashref();
+
+    say subtest_header $out->{freeform} => 'Our subtest name!';
+
+    # given a hashref, look for the coderef in the 'freeform' slot
+    say subtest_header $out => 'Our subtest name!';
+
+    # or with the reviled Test::Builder::Tester:
+    test_out subtest_header($out => 'Our subtest name!')
+        if subtest_header_needed;
+
+Returns true if the level of Test::More available will output a subtest header.
+
+Note that this function will attempt to load L<Test::More> and
+L<Perl::Version>.  If either of these packages are unavailable, it will
+L<Carp/croak>.
+
 =head1 USAGE WITH Test::Builder::Tester
 
 This package was created from code I was using to make it easier to test my
@@ -218,7 +289,7 @@ easy to make.
 
 =head1 SUBTESTS
 
-Subtest formatting can be done by passing a an integer "level" parameter to
+Subtest formatting can be done by passing an integer "level" parameter to
 C<counter()>; see the function's documentation for details.
 
 =head1 SEE ALSO
